@@ -11,12 +11,12 @@ use strict;
 
 package Curses::Toolkit::Event;
 BEGIN {
-  $Curses::Toolkit::Event::VERSION = '0.203';
+  $Curses::Toolkit::Event::VERSION = '0.204';
 }
 
 # ABSTRACT: base class for events
 
-use Params::Validate qw(:all);
+use Params::Validate qw(SCALAR ARRAYREF HASHREF CODEREF GLOB GLOBREF SCALARREF HANDLE BOOLEAN UNDEF validate validate_pos);
 
 
 sub new {
@@ -83,7 +83,7 @@ Curses::Toolkit::Event - base class for events
 
 =head1 VERSION
 
-version 0.203
+version 0.204
 
 =head1 DESCRIPTION
 
