@@ -11,14 +11,14 @@ use strict;
 
 package Curses::Toolkit::Event::Mouse::Click;
 BEGIN {
-  $Curses::Toolkit::Event::Mouse::Click::VERSION = '0.203';
+  $Curses::Toolkit::Event::Mouse::Click::VERSION = '0.204';
 }
 
 # ABSTRACT: event that is related to mouse click
 
 use parent qw(Curses::Toolkit::Event::Mouse);
 
-use Params::Validate qw(:all);
+use Params::Validate qw(SCALAR ARRAYREF HASHREF CODEREF GLOB GLOBREF SCALARREF HANDLE BOOLEAN UNDEF validate validate_pos);
 
 
 sub new {
@@ -103,7 +103,7 @@ Curses::Toolkit::Event::Mouse::Click - event that is related to mouse click
 
 =head1 VERSION
 
-version 0.203
+version 0.204
 
 =head1 DESCRIPTION
 
