@@ -11,14 +11,14 @@ use strict;
 
 package Curses::Toolkit::Event::Shape;
 BEGIN {
-  $Curses::Toolkit::Event::Shape::VERSION = '0.203';
+  $Curses::Toolkit::Event::Shape::VERSION = '0.204';
 }
 
 # ABSTRACT: event that is related to root window shape change
 
 use parent qw(Curses::Toolkit::Event);
 
-use Params::Validate qw(:all);
+use Params::Validate qw(SCALAR ARRAYREF HASHREF CODEREF GLOB GLOBREF SCALARREF HANDLE BOOLEAN UNDEF validate validate_pos);
 
 
 sub new {
@@ -83,7 +83,7 @@ Curses::Toolkit::Event::Shape - event that is related to root window shape chang
 
 =head1 VERSION
 
-version 0.203
+version 0.204
 
 =head1 DESCRIPTION
 
