@@ -11,14 +11,14 @@ use strict;
 
 package Curses::Toolkit::Role::Focusable;
 BEGIN {
-  $Curses::Toolkit::Role::Focusable::VERSION = '0.203';
+  $Curses::Toolkit::Role::Focusable::VERSION = '0.204';
 }
 
 # ABSTRACT: This role implements the fact that a widget can have focus
 
 use parent qw(Curses::Toolkit::Role);
 
-use Params::Validate qw(:all);
+use Params::Validate qw(SCALAR ARRAYREF HASHREF CODEREF GLOB GLOBREF SCALARREF HANDLE BOOLEAN UNDEF validate validate_pos);
 
 
 sub new {
@@ -84,7 +84,7 @@ Curses::Toolkit::Role::Focusable - This role implements the fact that a widget c
 
 =head1 VERSION
 
-version 0.203
+version 0.204
 
 =head1 DESCRIPTION
 
