@@ -11,10 +11,10 @@ use strict;
 
 package Curses::Toolkit::Signal;
 BEGIN {
-  $Curses::Toolkit::Signal::VERSION = '0.203';
+  $Curses::Toolkit::Signal::VERSION = '0.204';
 }
 
-use Params::Validate qw(:all);
+use Params::Validate qw(SCALAR ARRAYREF HASHREF CODEREF GLOB GLOBREF SCALARREF HANDLE BOOLEAN UNDEF validate validate_pos);
 
 
 sub new {
@@ -40,7 +40,7 @@ Curses::Toolkit::Signal
 
 =head1 VERSION
 
-version 0.203
+version 0.204
 
 =head1 DESCRIPTION
 
