@@ -11,10 +11,10 @@ use strict;
 
 package Curses::Toolkit::Signal::Content;
 BEGIN {
-  $Curses::Toolkit::Signal::Content::VERSION = '0.203';
+  $Curses::Toolkit::Signal::Content::VERSION = '0.204';
 }
 
-use Params::Validate qw(:all);
+use Params::Validate qw(SCALAR ARRAYREF HASHREF CODEREF GLOB GLOBREF SCALARREF HANDLE BOOLEAN UNDEF validate validate_pos);
 
 
 1;
@@ -28,7 +28,7 @@ Curses::Toolkit::Signal::Content
 
 =head1 VERSION
 
-version 0.203
+version 0.204
 
 =head1 DESCRIPTION
 
