@@ -11,7 +11,7 @@ use warnings;
 
 package Curses::Toolkit::Widget::HProgressBar;
 BEGIN {
-  $Curses::Toolkit::Widget::HProgressBar::VERSION = '0.203';
+  $Curses::Toolkit::Widget::HProgressBar::VERSION = '0.204';
 }
 
 # ABSTRACT: a horizontal progress bar widget
@@ -19,7 +19,7 @@ BEGIN {
 use Moose;
 use MooseX::Has::Sugar;
 use MooseX::FollowPBP;
-use Params::Validate qw(:all);
+use Params::Validate qw(SCALAR ARRAYREF HASHREF CODEREF GLOB GLOBREF SCALARREF HANDLE BOOLEAN UNDEF validate validate_pos);
 
 use Curses::Toolkit::Object::Coordinates;
 use Curses::Toolkit::Types;
@@ -133,7 +133,7 @@ Curses::Toolkit::Widget::HProgressBar - a horizontal progress bar widget
 
 =head1 VERSION
 
-version 0.203
+version 0.204
 
 =head1 DESCRIPTION
 
