@@ -11,14 +11,14 @@ use strict;
 
 package Curses::Toolkit::Widget::VBox;
 BEGIN {
-  $Curses::Toolkit::Widget::VBox::VERSION = '0.203';
+  $Curses::Toolkit::Widget::VBox::VERSION = '0.204';
 }
 
 # ABSTRACT: a vertical box widget
 
 use parent qw(Curses::Toolkit::Widget::Container);
 
-use Params::Validate qw(:all);
+use Params::Validate qw(SCALAR ARRAYREF HASHREF CODEREF GLOB GLOBREF SCALARREF HANDLE BOOLEAN UNDEF validate validate_pos);
 
 
 
@@ -96,8 +96,8 @@ sub _rebuild_children_coordinates {
             $height += $h;
             $remaining_space->subtract( { y2 => $h } );
             $children_heights[$idx] = $h;
-            $idx++;
             $children_padding[$idx] = { before => 0, after => 0 };
+            $idx++;
         }
     }
 
@@ -234,7 +234,7 @@ Curses::Toolkit::Widget::VBox - a vertical box widget
 
 =head1 VERSION
 
-version 0.203
+version 0.204
 
 =head1 DESCRIPTION
 
