@@ -11,13 +11,13 @@ use strict;
 
 package Curses::Toolkit::Widget::VPaned;
 BEGIN {
-  $Curses::Toolkit::Widget::VPaned::VERSION = '0.203';
+  $Curses::Toolkit::Widget::VPaned::VERSION = '0.204';
 }
 
 # ABSTRACT: a container with two panes arranged horizontally
 use parent qw(Curses::Toolkit::Widget::Paned);
 
-use Params::Validate qw(:all);
+use Params::Validate qw(SCALAR ARRAYREF HASHREF CODEREF GLOB GLOBREF SCALARREF HANDLE BOOLEAN UNDEF validate validate_pos);
 
 
 
@@ -100,7 +100,7 @@ Curses::Toolkit::Widget::VPaned - a container with two panes arranged horizontal
 
 =head1 VERSION
 
-version 0.203
+version 0.204
 
 =head1 DESCRIPTION
 
